@@ -41,6 +41,8 @@ class DelegateSafe(ApeSafe):
         """
         Create an ApeSafe from an address or a ENS name and use a default connection.
         """
+        
+        transaction_service[250] = "https://safe-txservice.fantom.network"
         backend_urls = {
             'gnosis': transaction_service,
             'yearn': {1: 'https://safe-transaction.mainnet.gnosis.yearn.tools/'}
@@ -111,7 +113,7 @@ class DelegateSafe(ApeSafe):
         # Pre-validated signatures are encoded as r=owner, s unused and v=1.
         # https://docs.gnosis.io/safe/docs/contracts_signatures/#pre-validated-signatures
         tx.signatures = b''.join([encode_abi(['address', 'uint'], [str(owner), 0]) + b'\x01' for owner in owners])
-        payload = tx.w3_tx.buildTransaction({'gas': str(chain.block_gas_limit)})
+        payload = tx.w3_tx.buildTransaction({'gasPrice': '100'})
         receipt = owners[0].transfer(payload['to'], payload['value'], gas_limit=payload['gas'], data=payload['data'])
 
         if 'ExecutionSuccess' not in receipt.events:
